==> safecheck-3.0.72.jar: filiale/wenxi/sqls/FetchPlanUserfiles-xin.sql <==
SELECT
    uf.f_user_id As id, --表档案id
    f_position AS f_weizhi, --安装位置
    gb.f_manufacturers AS f_maker, --气表厂家
    gm.f_meter_style AS f_diaphgram_size, --气表型号
    gb.f_meter_brand AS f_aliasname, --气表品牌
    gb.f_meter_type AS f_meter_type, --气表类型
    f_meter_base AS f_prior_reading, --气表底数
    f_meternumber AS f_meter_no, --表号
    f_aroundmeter AS f_flow_direction, --左右表
    f_metertitles As f_metertitles, --表封号
    f_meter_base As  f_metergasnums, --气表底数
    uf.f_initial_base AS f_initial_base, --表基数
    uf.f_total_fee, --累购金额
    case when uf.f_meter_classify='机表' then uf.f_meter_base else uf.f_total_gas end f_total_gas,--累购气量
    gb.f_collection_type, --购气类型(按金额，按气量)
    f_meter_classify,
    u.f_last_check_state,
    u.f_last_check_date,
    u.f_last_check_result,
    ui.f_contractdate,--合同时间
    ui.f_user_phone,--用户电话
    ui.f_rent_name,--租户姓名
    ui.f_zuhu_phone,--租户电话
    ui.f_user_state,--用户状态
    uf.f_table_state,--气表状态
    ui.f_ins_stop_date,--保费截止时间
    --tu.f_expiration_date as f_ins_stop_date,--上期保费截止时间
    uf.f_balance_amount,
    case when f_waterheaternum is null then '0' else f_waterheaternum end as f_waterheaternum, --热水器数量
    case when f_wallhangboilernum is null then '0' else f_wallhangboilernum end as f_wallhangboilernum,--壁挂炉数量
    case when f_kitchennum is null then '0' else f_kitchennum end as f_kitchennum,--灶具数量
    case when f_selfclosenum is null then '0' else f_selfclosenum end as f_selfclosenum,--自闭阀数量
    case when f_steelbellowsnum is null then '0' else f_steelbellowsnum end as f_steelbellowsnum,--不锈钢波纹管数量
    case when f_isalarm is null then '0' else f_isalarm end as f_isalarm,--有无报警器
    uf.f_userfiles_id,
    uf.version
FROM
    t_userfiles uf
        LEFT JOIN t_userinfo ui on uf.f_userinfo_id=ui.f_userinfo_id
        LEFT JOIN t_user_address u on uf.f_userinfo_id=u.f_userinfo_id
        LEFT JOIN t_gasmodel gm on uf.f_gasmodel_id = gm.id
        --left join t_userfees tu on tu.f_userinfo_id=ui.f_userinfo_id and tu.f_state = '有效'
        LEFT JOIN t_gasbrand gb ON uf.f_gasbrand_id = gb.id
WHERE
        uf.f_userinfo_id =  '{f_userid}' and (uf.f_table_state='正常' or uf.f_table_state='停用' or uf.f_table_state='待开通' or uf.f_table_state='封堵')

==> safecheck-3.1.66.jar: filiale/wenxi/sqls/FetchPlanUserfiles-xin.sql <==
SELECT
    uf.f_user_id As id, --表档案id
    f_position AS f_weizhi, --安装位置
    gb.f_manufacturers AS f_maker, --气表厂家
    gm.f_meter_style AS f_diaphgram_size, --气表型号
    gb.f_meter_brand AS f_aliasname, --气表品牌
    gb.f_meter_type AS f_meter_type, --气表类型
    f_meter_base AS f_prior_reading, --气表底数
    f_meternumber AS f_meter_no, --表号
    f_aroundmeter AS f_flow_direction, --左右表
    f_metertitles As f_metertitles, --表封号
    f_meter_base As  f_metergasnums, --气表底数
    uf.f_initial_base AS f_initial_base, --表基数
    uf.f_total_fee, --累购金额
    case when uf.f_meter_classify='机表' then uf.f_meter_base else uf.f_total_gas end f_total_gas,--累购气量
    gb.f_collection_type, --购气类型(按金额，按气量)
    f_meter_classify,
    u.f_last_check_state,
    u.f_last_check_date,
    u.f_last_check_result,
    ui.f_contractdate,--合同时间
    ui.f_user_phone,--用户电话
    ui.f_rent_name,--租户姓名
    ui.f_zuhu_phone,--租户电话
    ui.f_user_state,--用户状态
    uf.f_table_state,--气表状态
--     ui.f_ins_stop_date,--保费截止时间
    tu.f_expiration_date as f_ins_stop_date,--上期保费截止时间
    uf.f_balance_amount,
    case when f_waterheaternum is null then '0' else f_waterheaternum end as f_waterheaternum, --热水器数量
    case when f_wallhangboilernum is null then '0' else f_wallhangboilernum end as f_wallhangboilernum,--壁挂炉数量
    case when f_kitchennum is null then '0' else f_kitchennum end as f_kitchennum,--灶具数量
    case when f_selfclosenum is null then '0' else f_selfclosenum end as f_selfclosenum,--自闭阀数量
    case when f_steelbellowsnum is null then '0' else f_steelbellowsnum end as f_steelbellowsnum,--不锈钢波纹管数量
    case when f_isalarm is null then '0' else f_isalarm end as f_isalarm,--有无报警器
    uf.f_userfiles_id,
    uf.version
FROM
    t_userfiles uf
        LEFT JOIN t_userinfo ui on uf.f_userinfo_id=ui.f_userinfo_id
        LEFT JOIN t_user_address u on uf.f_userinfo_id=u.f_userinfo_id
        LEFT JOIN t_gasmodel gm on uf.f_gasmodel_id = gm.id
        LEFT JOIN (SELECT f_userinfo_id,MAX(f_expiration_date) AS f_expiration_date FROM t_userfees WHERE f_state = '有效' GROUP BY f_userinfo_id) tu on tu.f_userinfo_id=ui.f_userinfo_id
        LEFT JOIN t_gasbrand gb ON uf.f_gasbrand_id = gb.id
WHERE
        uf.f_userinfo_id =  '{f_userid}' and (uf.f_table_state='正常' or uf.f_table_state='停用' or uf.f_table_state='待开通' or uf.f_table_state='封堵')
